package com.laihua.projecthelper.stringxml

import com.laihua.projecthelper.implement.belongModule
import org.jdom2.Document
import org.jdom2.Element
import org.jdom2.input.SAXBuilder
import org.jdom2.output.Format
import org.jdom2.output.XMLOutputter
import java.io.File
import java.io.FileWriter


/**
 * Author: pengjunjing
 * Date: 2022/3/11
 * Description:string的xml文件解析类
 */
class StringXmlParse {

    companion object {

        const val resourcesStringDef = "resources"
        const val nameStringDef = "name"

    }

    /**
     * 将字符串文件解析成对象
     */
    fun parseToObj(stringXmlFile: File): StringXmlResCode {
        val document = SAXBuilder().build(stringXmlFile)
        val rootElement = document.rootElement
        val belongModule = stringXmlFile.belongModule()
        val stringXmlResCode = StringXmlResCode(stringXmlFile, belongModule)
        //读取resources节点下的内容
        if (belongModule != null && resourcesStringDef == rootElement.name) {
            val children = rootElement.children
            for (child in children) {
                if (child.name == "string") {
                    //获取string节点的数据
                    val stringElement =
                        StringElement(
                            stringXmlFile,
                            belongModule,
                            child.attributes[0].value,
                            child.value
                        )
                    stringXmlResCode.stringElementList.add(stringElement)
                }
            }

        }
        return stringXmlResCode
    }

    /**
     * 删除掉一个xml文件字符串内容
     */
    fun deleteStringXmlElement(stringElement: StringElement) {
        val document = SAXBuilder().build(stringElement.file)
        val rootElement = document.rootElement
        //找到与name=xxx相同的值
        val find: Element? = rootElement.children.find {
            it.getAttribute(nameStringDef).value == stringElement.attributeName
        }
        find?.let {
            rootElement.removeContent(it)
        }

        saveXML(stringElement.file, document)
    }

    private fun saveXML(file: File, doc: Document) {
        // 将doc对象输出到文件
        try {
            // 创建xml文件输出流
            val xmlOutPutter = XMLOutputter()

            // 创建文件输出流
            val writer = FileWriter(file)

            // 指定文档格式
            val fm: Format = Format.getPrettyFormat()
            xmlOutPutter.format = fm

            // 将doc写入到指定的文件中
            xmlOutPutter.output(doc, writer)
            writer.close()
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }
}